@@ -41,13 +41,13 @@ def register_mark_feature(features):
     features.default_features.append('mark')
 
 
-# Shadow
+#  Shadow
 
 @hooks.register('register_rich_text_features')
 def register_shadow_feature(features):
     feature_name = 'shadow'
     type_ = 'SHADOW'
-    tag = 'shadow'
+    tag = 'div'
 
     control = {
         'type': type_,
@@ -61,7 +61,16 @@ def register_shadow_feature(features):
 
     db_conversion = {
         'from_database_format': {tag: InlineStyleElementHandler(type_)},
-        'to_database_format': {'style_map': {type_: tag}},
+        'to_database_format': {
+            'style_map': {
+                type_: {
+                    'element': tag,
+                    'props': {
+                        'class': 'shadow',
+                    },
+                },
+            },
+        },
     }
 
     features.register_converter_rule('contentstate', feature_name, db_conversion)
